# encoding: utf-8

from __future__ import absolute_import, division, print_function, unicode_literals

from django.core.management import call_command
from django.core.management.base import BaseCommand


class Command(BaseCommand):
    help = "Completely rebuilds the search index by removing the old data and then updating."

    def handle(self, **options):
        call_command('clear_index', **options)
        call_command('update_index', **options)



# encoding: utf-8

from __future__ import absolute_import, division, print_function, unicode_literals

from django.core.management.base import BaseCommand
from django.conf import settings
from elasticsearch import Elasticsearch
from elasticsearch.helpers import bulk
from elasticsearch_app.search import LayerIndex, \
    MapIndex, DocumentIndex, ProfileIndex, GroupIndex, StoryIndex
from geonode.layers.models import Layer
from geonode.maps.models import Map
from geonode.documents.models import Document
from geonode.people.models import Profile
from geonode.groups.models import GroupProfile
from exchange.storyscapes.models.base import Story


class Command(BaseCommand):
    help = "Freshens the index for the given app(s)."

    def handle(self, **options):
        '''
        Repopulates the indices in elastic.
        '''
        es = Elasticsearch(settings.ES_URL)
        LayerIndex.init()
        MapIndex.init()
        DocumentIndex.init()
        ProfileIndex.init()
        GroupIndex.init()
        StoryIndex.init()

        body = {
            'analysis': {
                'analyzer': 'snowball'
            }
        }
        es.indices.put_settings(body, index='', ignore=400)

        bulk(client=es, actions=(index.indexing() for index in Layer.objects.all().iterator()))
        bulk(client=es, actions=(index.indexing() for index in Map.objects.all().iterator()))
        bulk(client=es, actions=(index.indexing() for index in Document.objects.all().iterator()))
        bulk(client=es, actions=(index.indexing() for index in Profile.objects.all().iterator()))
        bulk(client=es, actions=(index.indexing() for index in GroupProfile.objects.all().iterator()))
        bulk(client=es, actions=(index.indexing() for index in Story.objects.all().iterator()))



from geonode.layers.models import Layer
from geonode.maps.models import Map
from geonode.documents.models import Document
from geonode.people.models import Profile
from geonode.groups.models import GroupProfile
from exchange.storyscapes.models.base import Story
from django.db.models.signals import post_save
from django.dispatch import receiver


@receiver(post_save, sender=Layer)
def layer_index_post(sender, instance, **kwargs):
    instance.indexing()


@receiver(post_save, sender=Map)
def map_index_post(sender, instance, **kwargs):
    instance.indexing()


@receiver(post_save, sender=Document)
def document_index_post(sender, instance, **kwargs):
    instance.indexing()


@receiver(post_save, sender=Profile)
def profile_index_post(sender, instance, **kwargs):
    instance.indexing()


@receiver(post_save, sender=GroupProfile)
def group_index_post(sender, instance, **kwargs):
    instance.indexing()


@receiver(post_save, sender=Story)
def story_index_post(sender, instance, **kwargs):
    instance.indexing()



# To extend this app in your project, add a post_save
# signal for every model you wish to index.
# Be sure to update utils.py with any custom
# indexing for this model in the indexing() function.
# Otherwise, only the id will be indexed.
# <Model> = your model you wish to index
#
# @receiver(post_save, sender=<Model>)
# def <Model>_index_post(sender, instance, **kwargs):
#     instance.indexing()



# encoding: utf-8

from __future__ import absolute_import, division, print_function, unicode_literals

from django.core.management.base import BaseCommand
from django.conf import settings
from elasticsearch import Elasticsearch
from elasticsearch import TransportError


class Command(BaseCommand):
    help = "Clears the search index of all elasticsearchapp indices."

    def handle(self, **options):
        '''
        Clears the search index of all elasticsearchapp indices
        '''
        self.stdout.write("Removing all documents indexed by elasticsearchapp")
        es = Elasticsearch(settings.ES_URL)

        # Delete all the indices this application creates
        elasticsearchapp_indicies = [
            'layer-index',
            'map-index',
            'document-index',
            'group-index',
            'profile-index',
            'story-index'
        ]
        for index in elasticsearchapp_indicies:
            try:
                es.indices.delete(index=index)
            except TransportError:
                self.stdout.write("ERROR: Could not find index to delete: %s" % index)



from elasticsearch_dsl.connections import connections
from elasticsearch_dsl import DocType, Integer, String, Boolean, Date, Float
from django.conf import settings

connections.create_connection(hosts=[settings.ES_URL])


class LayerIndex(DocType):
    id = Integer()
    abstract = String(analyzer='snowball')
    category__gn_description = String(analyzer='snowball')
    csw_type = String(analyzer='snowball')
    csw_wkt_geometry = String(analyzer='snowball')
    detail_url = String(analyzer='snowball')
    owner__username = String(analyzer='snowball')
    owner__first_name = String(analyzer='snowball')
    owner__last_name = String(analyzer='snowball')
    is_published = Boolean()
    featured = Boolean()
    popular_count = Integer()
    share_count = Integer()
    rating = Integer()
    srid = String(analyzer='snowball')
    supplemental_information = String(analyzer='snowball')
    thumbnail_url = String(analyzer='snowball')
    uuid = String(analyzer='snowball')
    title = String(analyzer='snowball')
    date = Date()
    type = String(analyzer='snowball')
    subtype = String(analyzer='snowball')
    typename = String(analyzer='snowball')
    title_sortable = String()
    category = String(analyzer='snowball')
    bbox_left = Float()
    bbox_right = Float()
    bbox_bottom = Float()
    bbox_top = Float()
    temporal_extent_start = Date()
    temporal_extent_end = Date()
    keywords = String(multi=True, analyzer='snowball')
    regions = String(multi=True, analyzer='snowball')
    num_ratings = Integer()
    num_comments = Integer()
    geogig_link = String(analyzer='snowball')
    has_time = Boolean()

    class Meta:
        index = 'layer-index'


class MapIndex(DocType):
    id = Integer()
    abstract = String(analyzer='snowball')
    category__gn_description = String(analyzer='snowball')
    csw_type = String(analyzer='snowball')
    csw_wkt_geometry = String(analyzer='snowball')
    detail_url = String(analyzer='snowball')
    owner__username = String(analyzer='snowball')
    popular_count = Integer()
    share_count = Integer()
    rating = Integer()
    srid = String(analyzer='snowball')
    supplemental_information = String(analyzer='snowball')
    thumbnail_url = String(analyzer='snowball')
    uuid = String(analyzer='snowball')
    title = String(analyzer='snowball')
    date = Date()
    type = String(analyzer='snowball')
    title_sortable = String()
    category = String(analyzer='snowball')
    bbox_left = Float()
    bbox_right = Float()
    bbox_bottom = Float()
    bbox_top = Float()
    temporal_extent_start = Date()
    temporal_extent_end = Date()
    keywords = String(multi=True, analyzer='snowball')
    regions = String(multi=True, analyzer='snowball')
    num_ratings = Integer()
    num_comments = Integer()

    class Meta:
        index = 'map-index'


class DocumentIndex(DocType):
    id = Integer()
    abstract = String(analyzer='snowball')
    category__gn_description = String(analyzer='snowball')
    csw_type = String(analyzer='snowball')
    csw_wkt_geometry = String(analyzer='snowball')
    detail_url = String(analyzer='snowball')
    owner__username = String(analyzer='snowball')
    popular_count = Integer()
    share_count = Integer()
    rating = Integer()
    srid = String(analyzer='snowball')
    supplemental_information = String(analyzer='snowball')
    thumbnail_url = String(analyzer='snowball')
    uuid = String(analyzer='snowball')
    title = String(analyzer='snowball')
    date = Date()
    type = String(analyzer='snowball')
    title_sortable = String()
    category = String(analyzer='snowball')
    bbox_left = Float()
    bbox_right = Float()
    bbox_bottom = Float()
    bbox_top = Float()
    temporal_extent_start = Date()
    temporal_extent_end = Date()
    keywords = String(multi=True, analyzer='snowball')
    regions = String(multi=True, analyzer='snowball')
    num_ratings = Integer()
    num_comments = Integer()

    class Meta:
        index = 'document-index'


class ProfileIndex(DocType):
    id = Integer()
    username = String(analyzer='snowball')
    first_name = String(analyzer='snowball')
    last_name = String(analyzer='snowball')
    profile = String(analyzer='snowball')
    organization = String(analyzer='snowball')
    position = String(analyzer='snowball')
    type = String(analyzer='snowball')

    class Meta:
        index = 'profile-index'


class GroupIndex(DocType):
    id = Integer()
    title = String(analyzer='snowball')
    title_sortable = String()
    description = String(analyzer='snowball')
    json = String()
    type = String(analyzer='snowball')

    class Meta:
        index = 'group-index'


class StoryIndex(DocType):
    id = Integer()
    abstract = String(analyzer='snowball')
    category__gn_description = String(analyzer='snowball')
    distribution_description = String(analyzer='snowball')
    distribution_url = String(analyzer='snowball')
    owner__username = String(analyzer='snowball')
    popular_count = Integer()
    share_count = Integer()
    rating = Integer()
    thumbnail_url = String(analyzer='snowball')
    detail_url = String(analyzer='snowball')
    uuid = String(analyzer='snowball')
    title = String(analyzer='snowball')
    date = Date()
    type = String(analyzer='snowball')
    title_sortable = String()
    category = String(analyzer='snowball')
    bbox_left = Float()
    bbox_right = Float()
    bbox_bottom = Float()
    bbox_top = Float()
    temporal_extent_start = Date()
    temporal_extent_end = Date()
    keywords = String(multi=True, analyzer='snowball')
    regions = String(multi=True, analyzer='snowball')
    num_ratings = Integer()
    num_comments = Integer()
    num_chapters = Integer()
    owner__first_name = String(analyzer='snowball')
    owner__last_name = String(analyzer='snowball')
    is_published = Boolean()
    featured = Boolean()

    class Meta:
        index = 'story-index'



from setuptools import setup, find_packages


setup(
    name = "geonode-elasticsearch-app",
    version = "0.1.1",
    author = "tbrundage",
    author_email = "tbrundage@boundlessgeo.com",
    description = "Elasticsearch app for indexing GeoNode models via elasticsearch-dsl",
    long_description = "Elasticsearch app for indexing GeoNode models via elasticsearch-dsl",
    license = "GPLv2",
    url = "https://github.com/boundlessgeo/geonode-elasticsearch",
    download_url= "https://github.com/boundlessgeo/geonode-elasticsearch/archive/0.1.1.tar.gz",
    packages = find_packages(),
    classifiers = [
        "Environment :: Web Environment",
        "Intended Audience :: Developers",
        "License :: OSI Approved :: GNU General Public License v2 (GPLv2)",
        "Operating System :: OS Independent",
        "Programming Language :: Python",
        "Framework :: Django",
    ]
)



# encoding: utf-8

from __future__ import absolute_import, division, print_function, unicode_literals

from django.core.management.base import BaseCommand
from django.conf import settings
from elasticsearch import Elasticsearch


class Command(BaseCommand):
    help = "Clears out haystack's modelresult index from elasticsearch."

    def handle(self, **options):
        '''
        Clears out haystack's modelresult index from elasticsearch
        '''
        self.stdout.write("Removing modelresult index from elasticsearch")
        es = Elasticsearch(settings.ES_URL)

        try:
            es.indices.delete(index='modelresult')
        except TransportError:
            self.stdout.write("ERROR: Could not find index to delete: modelresult")
